import { Observable } from 'rxjs';
import { take } from 'rxjs/operators';

import { Injectable } from '@angular/core';
import {
  CanActivate,
  ActivatedRouteSnapshot,
  RouterStateSnapshot,
  UrlTree,
  Router
} from '@angular/router';

import { Store } from '@ngrx/store';

import { PiService } from '@ucap/ng-pi';

import { LoginActions } from '@ucap/ng-store-authentication';

import { AppAuthenticationService } from '@app/services/app-authentication.service';

@Injectable({
  providedIn: 'root'
})
export class AppAuthenticationGuard implements CanActivate {
  constructor(
    private piService: PiService,
    private appAuthenticationService: AppAuthenticationService,
    private store: Store<any>,
    private router: Router
  ) {}

  canActivate(
    route: ActivatedRouteSnapshot,
    state: RouterStateSnapshot
  ):
    | boolean
    | UrlTree
    | Observable<boolean | UrlTree>
    | Promise<boolean | UrlTree> {
    return new Promise<boolean | UrlTree>((resolve, reject) => {
      if (this.appAuthenticationService.loggedIn()) {
        resolve(true);
      } else {
        const userStore = this.appAuthenticationService.useAutoLogin();
        if (!!userStore) {
          const loginSession = this.appAuthenticationService.loginSession;

          const onWebLoginFailure = (error: any) => {
            userStore.settings.general.autoLogin = false;
            this.appAuthenticationService.userStore = userStore;

            this.router.navigateByUrl('/account/login');
            resolve(false);
          };

          this.piService
            .login2({
              companyCode: userStore.companyCode,
              loginId: userStore.loginId,
              loginPw: userStore.loginPw,
              deviceType: loginSession.deviceType
            })
            .pipe(take(1))
            .subscribe(
              (res) => {
                if ('success' !== res.status.toLowerCase()) {
                  onWebLoginFailure(res.status);
                  return;
                } else {
                  this.store.dispatch(
                    LoginActions.webLoginSuccess({
                      companyCode: userStore.companyCode,
                      loginId: userStore.loginId,
                      loginPw: userStore.loginPw,
                      autoLogin: true,
                      rememberMe: userStore.rememberMe,
                      login2Response: res
                    })
                  );
                  resolve(true);
                  return;
                }
              },
              (error) => {
                onWebLoginFailure(error);
              },
              () => {}
            );
        } else {
          this.router.navigateByUrl('/account/login');
          resolve(false);
        }
      }
    });
  }
}
